@@ -462,6 +462,8 @@ int get_lock(const char *File)
       if (errno == ENOLCK)
       {
 	 g_warning(_("Not using locking for nfs mounted lock file %s"), File);
+	 unlink(File);
+	 close(FD);
 	 return dup(0);       // Need something for the caller to close	 
       }      
       
